@@ -1,8 +1,8 @@
 import numpy as np
-import pandas as pd
 from scipy.stats import logistic
 from sklearn.datasets import make_classification
-import pandas as pd
+import csv
+
 
 class StreamGenerator:
     """ Data streams generator for both stationary and drifting data streams.
@@ -50,7 +50,7 @@ class StreamGenerator:
         self,
         n_chunks=250,
         chunk_size=200,
-        random_state=1410,
+        random_state=None,
         n_drifts=0,
         concept_sigmoid_spacing=None,
         n_classes=2,
@@ -67,7 +67,7 @@ class StreamGenerator:
     ):
         self.n_chunks = n_chunks
         self.chunk_size = chunk_size
-        self.random_state = random_state
+        self.random_state = random_state if random_state is not None else np.random.randint(10000)
         self.n_drifts = n_drifts
         self.concept_sigmoid_spacing = concept_sigmoid_spacing
         self.n_classes = n_classes
@@ -110,7 +110,7 @@ class StreamGenerator:
             else np.ones(self.n_samples)
         )
 
-        # Szybka naprawa, żeby dało się przepuścić podzielną z resztą liczbę dryfów
+        # Ensuring that the probabilities are divisible by the number of drifts
         probabilities = np.ones(self.n_chunks * self.chunk_size) * _probabilities[-1]
         probabilities[: _probabilities.shape[0]] = _probabilities
 
@@ -118,8 +118,7 @@ class StreamGenerator:
 
     def _make_classification(self):
         np.random.seed(self.random_state)
-        # To jest dziwna koncepcja z wagami z wierszy macierzy diagonalnej ale działa.
-        # Jak coś działa to jest dobre.
+        # Using concept with weights from the rows of a diagonal matrix
         self.concepts = np.array(
             [
                 [
@@ -150,10 +149,10 @@ class StreamGenerator:
                 self.concept_sigmoid_spacing, self.n_drifts
             )
 
-            # Szum
+            # Noise
             self.concept_noise = np.random.rand(self.n_samples)
 
-            # Inkrementalny
+            # Incremental drift
             if self.incremental:
                 # Something
                 self.a_ind = np.zeros(self.concept_probabilities.shape).astype(int)
@@ -173,9 +172,9 @@ class StreamGenerator:
                 b = b * (self.concept_probabilities)
                 c = a + b
 
-            # Gradualny
+            # Gradual drift
             else:
-                # Selekcja klas
+                # Class selection
                 self.concept_selector = (
                     self.concept_probabilities < self.concept_noise
                 ).astype(int)
@@ -191,7 +190,7 @@ class StreamGenerator:
                             np.where(self.concept_selector[start:end] == 0)[0] + start
                         ] = i + (i % 2)
 
-        # Selekcja klas na potrzeby doboru balansu
+        # Class selection for balancing
         self.balance_noise = np.random.rand(self.n_samples)
 
         # Case of same size of all classes
@@ -223,7 +222,6 @@ class StreamGenerator:
                 self.class_probabilities *= self.balance_amplitude
                 self.class_probabilities += 0.5
 
-                # Will it work?
                 self.class_selector = (
                     self.class_probabilities < self.balance_noise
                 ).astype(int)
@@ -243,21 +241,21 @@ class StreamGenerator:
                                                               self.chunk_size))
 
                 self.class_selector[:, 0] = 0
-                self.class_selector[:,-1] = 1
+                self.class_selector[:, -1] = 1
 
-                self.class_selector = (self.class_selector > self.class_probabilities[:,np.newaxis]).astype(int)
+                self.class_selector = (self.class_selector > self.class_probabilities[:, np.newaxis]).astype(int)
 
                 self.class_selector = np.ravel(self.class_selector)
 
-        # Przypisanie klas i etykiet
+        # Assigning classes and labels
         if self.n_drifts > 0:
-            # Jeśli dryfy, przypisz koncepty
+            # If there are drifts - assign concepts
             if self.incremental:
                 self.concepts = c
             else:
                 self.concepts = np.choose(self.concept_selector, self.concepts)
         else:
-            # Jeśli nie, przecież jest jeden, więc spłaszcz
+            # If not - flatten
             self.concepts = np.squeeze(self.concepts)
 
         # Assign objects to real classes
@@ -356,7 +354,7 @@ class StreamGenerator:
                 self.n_drifts,
                 int(self.y_flip[0] * 100),
                 int(self.y_flip[1] * 100),
-                ("%i_%i_%.0f" % (self.weights[0],self.weights[1],self.weights[2]*100)),
+                ("%i_%i_%.0f" % (self.weights[0], self.weights[1], self.weights[2]*100)),
                 int(self.chunk_size * self.n_chunks),
             )
         elif type(self.y_flip) != tuple and type(self.weights) == tuple and len(self.weights) == 3:
@@ -369,7 +367,7 @@ class StreamGenerator:
                 self.random_state,
                 self.n_drifts,
                 int(self.y_flip * 100),
-                ("%i_%i_%.0f" % (self.weights[0],self.weights[1],self.weights[2]*100)),
+                ("%i_%i_%.0f" % (self.weights[0], self.weights[1], self.weights[2]*100)),
                 int(self.chunk_size * self.n_chunks)
             )
         elif type(self.y_flip) == tuple and type(self.weights) == tuple and len(self.weights) == 2:
@@ -383,7 +381,7 @@ class StreamGenerator:
                 self.n_drifts,
                 int(self.y_flip[0] * 100),
                 int(self.y_flip[1] * 100),
-                ("%.0f_%.0f" % (self.weights[0]*100,self.weights[1]*100)),
+                ("%.0f_%.0f" % (self.weights[0]*100, self.weights[1]*100)),
                 int(self.chunk_size * self.n_chunks),
             )
         elif type(self.y_flip) != tuple and type(self.weights) == tuple and len(self.weights) == 2:
@@ -396,10 +394,17 @@ class StreamGenerator:
                 self.random_state,
                 self.n_drifts,
                 int(self.y_flip * 100),
-                ("%.0f_%.0f" % (self.weights[0]*100,self.weights[1]*100)),
+                ("%.0f_%.0f" % (self.weights[0]*100, self.weights[1]*100)),
                 int(self.chunk_size * self.n_chunks)
             )
 
+    def __next__(self):
+        while not self.is_dry():
+            yield self.get_chunk()
+
+    def __iter__(self):
+        return next(self)
+
     def save_to_arff(self, filepath):
         """
         Save generated stream to the ARFF format file.
@@ -449,7 +454,6 @@ class StreamGenerator:
         ds = np.concatenate([X, y[:, np.newaxis]], axis=1)
         np.save(filepath, ds)
 
-
     def save_to_csv(self, filepath):
         """
         Save generated stream to the csv format file.
@@ -459,9 +463,10 @@ class StreamGenerator:
         """
         X, y = self._make_classification()
 
-        ds = np.concatenate([X, y[:, np.newaxis]], axis=1)
-
-        pdds = pd.DataFrame(ds)
-        pdds.infer_objects()
-        pdds.iloc[: , -1] = pdds.iloc[: , -1].astype(int)
-        pdds.to_csv(filepath, header=None,index=None)
+        with open(filepath, 'w+') as f:
+            writer = csv.writer(f)
+            for row_x, row_y in zip(X, y):
+                row = list()
+                row.extend(row_x)
+                row.append(int(row_y))
+                writer.writerow(row)
