@@ -2,10 +2,12 @@ from .ARFFParser import ARFFParser
 from .CSVParser import CSVParser
 from .NPYParser import NPYParser
 from .StreamGenerator import StreamGenerator
+from .SemiSyntheticStreamGenerator import SemiSyntheticStreamGenerator
 
 __all__ = [
     "ARFFParser",
     "StreamGenerator",
     "CSVParser",
     "NPYParser",
+    "SemiSyntheticStreamGenerator"
 ]
